@@ -1,16 +1,16 @@
-# Copyright (c) 2014, 2023, Oracle and/or its affiliates.
+# Copyright (c) 2014, 2025, Oracle and/or its affiliates.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2.0, as
 # published by the Free Software Foundation.
 #
-# This program is also distributed with certain software (including
+# This program is designed to work with certain software (including
 # but not limited to OpenSSL) that is licensed under separate terms,
 # as designated in a particular file or component or in included license
-# documentation.  The authors of MySQL hereby grant you an
+# documentation. The authors of MySQL hereby grant you an
 # additional permission to link the program and your derivative works
-# with the separately licensed software that they have included with
-# MySQL.
+# with the separately licensed software that they have either included with
+# the program or referenced in the documentation.
 #
 # Without limiting anything contained in the foregoing, this file,
 # which is part of MySQL Connector/Python, is also subject to the
@@ -26,7 +26,7 @@
 # along with this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
 
-# mypy: disable-error-code="arg-type,index"
+# mypy: disable-error-code="arg-type"
 
 """Connection class using the C Extension."""
 
@@ -34,12 +34,25 @@ import os
 import platform
 import socket
 import sys
+import warnings
 
-from typing import Any, Dict, List, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Any,
+    BinaryIO,
+    Dict,
+    List,
+    NoReturn,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
 from . import version
-from .abstracts import MySQLConnectionAbstract
-from .constants import CharacterSet, ClientFlag, FieldFlag, ServerFlag, ShutdownType
+from ._decorating import cmd_refresh_verify_options
+from .abstracts import CMySQLPrepStmt, MySQLConnectionAbstract
+from .constants import ClientFlag, FieldFlag, FieldType, ServerFlag, ShutdownType
 from .conversion import MySQLConverter
 from .errors import (
     InterfaceError,
@@ -58,26 +71,27 @@ from .types import (
     StatsPacketType,
     StrOrBytes,
 )
+from .utils import (
+    import_object,
+    warn_ciphersuites_deprecated,
+    warn_tls_version_deprecated,
+)
 
 HAVE_CMYSQL = False
 
 try:
     import _mysql_connector
 
-    from _mysql_connector import MySQLInterfaceError, MySQLPrepStmt
+    from _mysql_connector import MySQLInterfaceError
 
     from .cursor_cext import (
         CMySQLCursor,
         CMySQLCursorBuffered,
         CMySQLCursorBufferedDict,
-        CMySQLCursorBufferedNamedTuple,
         CMySQLCursorBufferedRaw,
         CMySQLCursorDict,
-        CMySQLCursorNamedTuple,
         CMySQLCursorPrepared,
         CMySQLCursorPreparedDict,
-        CMySQLCursorPreparedNamedTuple,
-        CMySQLCursorPreparedRaw,
         CMySQLCursorRaw,
     )
 
@@ -163,7 +177,7 @@ class CMySQLConnection(MySQLConnectionAbstract):
         self._server_version = self._check_server_version(
             self._handshake["server_version_original"]
         )
-        CharacterSet.set_mysql_version(self._server_version)
+        self._character_set.set_mysql_version(self._server_version)
 
     @property
     def _server_status(self) -> int:
@@ -179,12 +193,8 @@ class CMySQLConnection(MySQLConnectionAbstract):
         if self._cmysql:
             self._cmysql.set_load_data_local_infile_option(path)
 
-    def set_unicode(self, value: bool = True) -> None:
-        """Toggle unicode mode
-
-        Set whether we return string fields as unicode or not.
-        Default is True.
-        """
+    @MySQLConnectionAbstract.use_unicode.setter  # type: ignore
+    def use_unicode(self, value: bool) -> None:
         self._use_unicode = value
         if self._cmysql:
             self._cmysql.use_unicode(value)
@@ -204,9 +214,37 @@ class CMySQLConnection(MySQLConnectionAbstract):
             self._cmysql.autocommit(value)
             self._autocommit = value
         except MySQLInterfaceError as err:
-            raise get_mysql_exception(
-                msg=err.msg, errno=err.errno, sqlstate=err.sqlstate
-            ) from err
+            if hasattr(err, "errno"):
+                raise get_mysql_exception(
+                    err.errno, msg=err.msg, sqlstate=err.sqlstate
+                ) from err
+            raise InterfaceError(str(err)) from err
+
+    @property
+    def read_timeout(self) -> Optional[int]:
+        return self._read_timeout
+
+    @read_timeout.setter
+    def read_timeout(self, timeout: int) -> None:
+        raise ProgrammingError(
+            """
+            The use of read_timeout after the connection has been established is unsupported
+            in the C-Extension
+            """
+        )
+
+    @property
+    def write_timeout(self) -> Optional[int]:
+        return self._write_timeout
+
+    @write_timeout.setter
+    def write_timeout(self, timeout: int) -> None:
+        raise ProgrammingError(
+            """
+            Changes in write_timeout after the connection has been established is unsupported
+            in the C-Extension
+            """
+        )
 
     @property
     def database(self) -> str:
@@ -219,30 +257,33 @@ class CMySQLConnection(MySQLConnectionAbstract):
         try:
             self._cmysql.select_db(value)
         except MySQLInterfaceError as err:
-            raise get_mysql_exception(
-                msg=err.msg, errno=err.errno, sqlstate=err.sqlstate
-            ) from err
+            if hasattr(err, "errno"):
+                raise get_mysql_exception(
+                    err.errno, msg=err.msg, sqlstate=err.sqlstate
+                ) from err
+            raise InterfaceError(str(err)) from err
 
     @property
-    def in_transaction(self) -> int:
+    def in_transaction(self) -> bool:
         """MySQL session has started a transaction"""
-        return self._server_status & ServerFlag.STATUS_IN_TRANS
+        return bool(self._server_status & ServerFlag.STATUS_IN_TRANS)
 
     def _open_connection(self) -> None:
-        charset_name = CharacterSet.get_info(self._charset_id)[0]
+        charset_name = self._character_set.get_info(self._charset_id)[0]
         # pylint: disable=c-extension-no-member
         self._cmysql = _mysql_connector.MySQL(
             buffered=self._buffered,
             raw=self._raw,
             charset_name=charset_name,
             connection_timeout=(self._connection_timeout or 0),
-            use_unicode=self._use_unicode,
+            use_unicode=self.use_unicode,
             auth_plugin=self._auth_plugin,
             plugin_dir=self._plugin_dir,
         )
         # pylint: enable=c-extension-no-member
         if not self.isset_client_flag(ClientFlag.CONNECT_ARGS):
             self._conn_attrs = {}
+
         cnx_kwargs = {
             "host": self._host,
             "user": self._user,
@@ -252,7 +293,7 @@ class CMySQLConnection(MySQLConnectionAbstract):
             "password3": self._password3,
             "database": self._database,
             "port": self._port,
-            "client_flags": self._client_flags,
+            "client_flags": self.client_flags,
             "unix_socket": self._unix_socket,
             "compress": self._compress,
             "ssl_disabled": True,
@@ -261,7 +302,14 @@ class CMySQLConnection(MySQLConnectionAbstract):
             "load_data_local_dir": self._allow_local_infile_in_path,
             "oci_config_file": self._oci_config_file,
             "oci_config_profile": self._oci_config_profile,
-            "fido_callback": self._fido_callback,
+            "webauthn_callback": (
+                import_object(self._webauthn_callback)
+                if isinstance(self._webauthn_callback, str)
+                else self._webauthn_callback
+            ),
+            "openid_token_file": self._openid_token_file,
+            "read_timeout": self._read_timeout if self._read_timeout else 0,
+            "write_timeout": self._write_timeout if self._write_timeout else 0,
         }
 
         tls_versions = self._ssl.get("tls_versions")
@@ -269,8 +317,12 @@ class CMySQLConnection(MySQLConnectionAbstract):
             tls_versions.sort(reverse=True)  # type: ignore[union-attr]
             tls_versions = ",".join(tls_versions)
         if self._ssl.get("tls_ciphersuites") is not None:
-            ssl_ciphersuites = self._ssl.get("tls_ciphersuites")[0]
-            tls_ciphersuites = self._ssl.get("tls_ciphersuites")[1]
+            ssl_ciphersuites = (
+                self._ssl.get("tls_ciphersuites")[0] or None  # type: ignore[index]
+            )  # if it's the empty string, then use `None` instead
+            tls_ciphersuites = self._ssl.get("tls_ciphersuites")[  # type: ignore[index]
+                1
+            ]
         else:
             ssl_ciphersuites = None
             tls_ciphersuites = None
@@ -304,15 +356,31 @@ class CMySQLConnection(MySQLConnectionAbstract):
             if self.converter:
                 self.converter.str_fallback = self._converter_str_fallback
         except MySQLInterfaceError as err:
-            raise get_mysql_exception(
-                msg=err.msg, errno=err.errno, sqlstate=err.sqlstate
-            ) from err
+            if hasattr(err, "errno"):
+                raise get_mysql_exception(
+                    err.errno, msg=err.msg, sqlstate=err.sqlstate
+                ) from err
+            raise InterfaceError(str(err)) from err
 
         self._do_handshake()
 
+        if (
+            not self._ssl_disabled
+            and hasattr(self._cmysql, "get_ssl_cipher")
+            and callable(self._cmysql.get_ssl_cipher)
+        ):
+            # Raise a deprecation warning if deprecated TLS version
+            # or cipher is being used.
+
+            # `get_ssl_cipher()` returns the name of the cipher being used.
+            cipher = self._cmysql.get_ssl_cipher()
+            for tls_version in set(self._ssl.get("tls_versions", [])):
+                warn_tls_version_deprecated(tls_version)
+                warn_ciphersuites_deprecated(cipher, tls_version)
+
     def close(self) -> None:
-        """Disconnect from the MySQL server"""
         if self._span and self._span.is_recording():
+            # pylint: disable=possibly-used-before-assignment
             record_exception_event(self._span, sys.exc_info()[1])
 
         if not self._cmysql:
@@ -324,9 +392,11 @@ class CMySQLConnection(MySQLConnectionAbstract):
         except MySQLInterfaceError as err:
             if OTEL_ENABLED:
                 record_exception_event(self._span, err)
-            raise get_mysql_exception(
-                msg=err.msg, errno=err.errno, sqlstate=err.sqlstate
-            ) from err
+            if hasattr(err, "errno"):
+                raise get_mysql_exception(
+                    err.errno, msg=err.msg, sqlstate=err.sqlstate
+                ) from err
+            raise InterfaceError(str(err)) from err
         finally:
             if OTEL_ENABLED:
                 end_span(self._span)
@@ -390,9 +460,11 @@ class CMySQLConnection(MySQLConnectionAbstract):
                     raise InterfaceError("Query should not return more than 1 row")
             self._cmysql.free_result()
         except MySQLInterfaceError as err:
-            raise get_mysql_exception(
-                msg=err.msg, errno=err.errno, sqlstate=err.sqlstate
-            ) from err
+            if hasattr(err, "errno"):
+                raise get_mysql_exception(
+                    err.errno, msg=err.msg, sqlstate=err.sqlstate
+                ) from err
+            raise InterfaceError(str(err)) from err
 
         return first_row
 
@@ -412,7 +484,8 @@ class CMySQLConnection(MySQLConnectionAbstract):
         binary: bool = False,
         columns: Optional[List[DescriptionType]] = None,
         raw: Optional[bool] = None,
-        prep_stmt: Optional[MySQLPrepStmt] = None,
+        prep_stmt: Optional[CMySQLPrepStmt] = None,
+        **kwargs: Any,
     ) -> Tuple[List[RowType], Optional[CextEofPacketType]]:
         """Get all or a subset of rows returned by the MySQL server"""
         unread_result = prep_stmt.have_result_set if prep_stmt else self.unread_result
@@ -422,30 +495,48 @@ class CMySQLConnection(MySQLConnectionAbstract):
         if raw is None:
             raw = self._raw
 
-        rows: List[Tuple[Any, ...]] = []
+        rows: List[Tuple] = []
         if count is not None and count <= 0:
             raise AttributeError("count should be 1 or higher, or None")
 
         counter = 0
         try:
             fetch_row = prep_stmt.fetch_row if prep_stmt else self._cmysql.fetch_row
-            if self.converter:
-                # When using a converter class, the C extension should not
+            if self.converter or raw:
+                # When using a converter class or `raw`, the C extension should not
                 # convert the values. This can be accomplished by setting
                 # the raw option to True.
                 self._cmysql.raw(True)
+
             row = fetch_row()
             while row:
+                row = list(row)
+
+                if not self._cmysql.raw() and not raw:
+                    # `not _cmysql.raw()` means the c-ext conversion layer will happen.
+                    # `not raw` means the caller wants conversion to happen.
+                    # For a VECTOR type, the c-ext conversion layer cannot return
+                    # an array.array type since such a type isn't part of the Python/C
+                    # API. Therefore, the c-ext will treat VECTOR types as if they
+                    # were BLOB types - be returned as `bytes` always.
+                    # Hence, a VECTOR type must be cast to an array.array type using the
+                    # built-in python conversion layer.
+                    # pylint: disable=protected-access
+                    for i, dsc in enumerate(self._columns):
+                        if dsc[1] == FieldType.VECTOR:
+                            row[i] = MySQLConverter._vector_to_python(row[i])
+
                 if not self._raw and self.converter:
-                    row = list(row)
                     for i, _ in enumerate(row):
                         if not raw:
                             row[i] = self.converter.to_python(self._columns[i], row[i])
-                    row = tuple(row)
-                rows.append(row)
+
+                rows.append(tuple(row))
                 counter += 1
+
                 if count and counter == count:
                     break
+
                 row = fetch_row()
             if not row:
                 _eof: Optional[CextEofPacketType] = self.fetch_eof_columns(prep_stmt)[
@@ -461,11 +552,13 @@ class CMySQLConnection(MySQLConnectionAbstract):
         except MySQLInterfaceError as err:
             if prep_stmt:
                 prep_stmt.free_result()
-                raise InterfaceError(str(err)) from err
-            self.free_result()
-            raise get_mysql_exception(
-                msg=err.msg, errno=err.errno, sqlstate=err.sqlstate
-            ) from err
+            else:
+                self.free_result()
+            if hasattr(err, "errno"):
+                raise get_mysql_exception(
+                    err.errno, msg=err.msg, sqlstate=err.sqlstate
+                ) from err
+            raise InterfaceError(str(err)) from err
 
         return rows, _eof
 
@@ -474,8 +567,9 @@ class CMySQLConnection(MySQLConnectionAbstract):
         binary: bool = False,
         columns: Optional[List[DescriptionType]] = None,
         raw: Optional[bool] = None,
-        prep_stmt: Optional[MySQLPrepStmt] = None,
-    ) -> Tuple[Optional[RowType], CextEofPacketType]:
+        prep_stmt: Optional[CMySQLPrepStmt] = None,
+        **kwargs: Any,
+    ) -> Tuple[Optional[RowType], Optional[CextEofPacketType]]:
         """Get the next rows returned by the MySQL server"""
         try:
             rows, eof = self.get_rows(
@@ -521,12 +615,14 @@ class CMySQLConnection(MySQLConnectionAbstract):
         try:
             self._cmysql.select_db(database)
         except MySQLInterfaceError as err:
-            raise get_mysql_exception(
-                msg=err.msg, errno=err.errno, sqlstate=err.sqlstate
-            ) from err
+            if hasattr(err, "errno"):
+                raise get_mysql_exception(
+                    err.errno, msg=err.msg, sqlstate=err.sqlstate
+                ) from err
+            raise InterfaceError(str(err)) from err
 
     def fetch_eof_columns(
-        self, prep_stmt: Optional[MySQLPrepStmt] = None
+        self, prep_stmt: Optional[CMySQLPrepStmt] = None
     ) -> CextResultType:
         """Fetch EOF and column information"""
         have_result_set = (
@@ -573,7 +669,11 @@ class CMySQLConnection(MySQLConnectionAbstract):
 
         return None
 
-    def cmd_stmt_prepare(self, statement: bytes) -> MySQLPrepStmt:
+    def cmd_stmt_prepare(
+        self,
+        statement: bytes,
+        **kwargs: Any,
+    ) -> CMySQLPrepStmt:
         """Prepares the SQL statement"""
         if not self._cmysql:
             raise OperationalError("MySQL Connection not available")
@@ -581,17 +681,29 @@ class CMySQLConnection(MySQLConnectionAbstract):
         try:
             stmt = self._cmysql.stmt_prepare(statement)
             stmt.converter_str_fallback = self._converter_str_fallback
-            return stmt
+            return CMySQLPrepStmt(stmt)
         except MySQLInterfaceError as err:
+            if hasattr(err, "errno"):
+                raise get_mysql_exception(
+                    err.errno, msg=err.msg, sqlstate=err.sqlstate
+                ) from err
             raise InterfaceError(str(err)) from err
 
+    @with_context_propagation
     def cmd_stmt_execute(
-        self, statement_id: MySQLPrepStmt, *args: Any
+        self,
+        statement_id: CMySQLPrepStmt,
+        *args: Any,
+        **kwargs: Any,
     ) -> Optional[Union[CextEofPacketType, CextResultType]]:
         """Executes the prepared statement"""
         try:
-            statement_id.stmt_execute(*args)
+            statement_id.stmt_execute(*args, query_attrs=self.query_attrs)
         except MySQLInterfaceError as err:
+            if hasattr(err, "errno"):
+                raise get_mysql_exception(
+                    err.errno, msg=err.msg, sqlstate=err.sqlstate
+                ) from err
             raise InterfaceError(str(err)) from err
 
         self._columns = []
@@ -603,17 +715,39 @@ class CMySQLConnection(MySQLConnectionAbstract):
         self._unread_result = True
         return self.fetch_eof_columns(statement_id)
 
-    def cmd_stmt_close(self, statement_id: MySQLPrepStmt) -> None:
+    def cmd_stmt_close(
+        self,
+        statement_id: CMySQLPrepStmt,  # type: ignore[override]
+        **kwargs: Any,
+    ) -> None:
         """Closes the prepared statement"""
         if self._unread_result:
             raise InternalError("Unread result found")
-        statement_id.stmt_close()
+        try:
+            statement_id.stmt_close()
+        except MySQLInterfaceError as err:
+            if hasattr(err, "errno"):
+                raise get_mysql_exception(
+                    err.errno, msg=err.msg, sqlstate=err.sqlstate
+                ) from err
+            raise InterfaceError(str(err)) from err
 
-    def cmd_stmt_reset(self, statement_id: MySQLPrepStmt) -> None:
+    def cmd_stmt_reset(
+        self,
+        statement_id: CMySQLPrepStmt,  # type: ignore[override]
+        **kwargs: Any,
+    ) -> None:
         """Resets the prepared statement"""
         if self._unread_result:
             raise InternalError("Unread result found")
-        statement_id.stmt_reset()
+        try:
+            statement_id.stmt_reset()
+        except MySQLInterfaceError as err:
+            if hasattr(err, "errno"):
+                raise get_mysql_exception(
+                    err.errno, msg=err.msg, sqlstate=err.sqlstate
+                ) from err
+            raise InterfaceError(str(err)) from err
 
     @with_context_propagation
     def cmd_query(
@@ -622,14 +756,19 @@ class CMySQLConnection(MySQLConnectionAbstract):
         raw: Optional[bool] = None,
         buffered: bool = False,
         raw_as_string: bool = False,
+        **kwargs: Any,
     ) -> Optional[Union[CextEofPacketType, CextResultType]]:
-        """Send a query to the MySQL server"""
         self.handle_unread_result()
         if raw is None:
             raw = self._raw
         try:
             if not isinstance(query, bytes):
                 query = query.encode("utf-8")
+
+            # Set/Reset internal state related to query execution
+            self._query = query
+            self._local_infile_filenames = None
+
             self._cmysql.query(
                 query,
                 raw=raw,
@@ -638,9 +777,11 @@ class CMySQLConnection(MySQLConnectionAbstract):
                 query_attrs=self.query_attrs,
             )
         except MySQLInterfaceError as err:
-            raise get_mysql_exception(
-                err.errno, msg=err.msg, sqlstate=err.sqlstate
-            ) from err
+            if hasattr(err, "errno"):
+                raise get_mysql_exception(
+                    err.errno, msg=err.msg, sqlstate=err.sqlstate
+                ) from err
+            raise InterfaceError(str(err)) from err
         except AttributeError as err:
             addr = (
                 self._unix_socket if self._unix_socket else f"{self._host}:{self._port}"
@@ -663,18 +804,19 @@ class CMySQLConnection(MySQLConnectionAbstract):
         buffered: Optional[bool] = None,
         raw: Optional[bool] = None,
         prepared: Optional[bool] = None,
-        cursor_class: Optional[Type[CMySQLCursor]] = None,
+        cursor_class: Optional[Type[CMySQLCursor]] = None,  # type: ignore[override]
         dictionary: Optional[bool] = None,
-        named_tuple: Optional[bool] = None,
+        read_timeout: Optional[int] = None,
+        write_timeout: Optional[int] = None,
     ) -> CMySQLCursor:
         """Instantiates and returns a cursor using C Extension
 
         By default, CMySQLCursor is returned. Depending on the options
         while connecting, a buffered and/or raw cursor is instantiated
         instead. Also depending upon the cursor options, rows can be
-        returned as dictionary or named tuple.
+        returned as a dictionary or a tuple.
 
-        Dictionary and namedtuple based cursors are available with buffered
+        Dictionary based cursors are available with buffered
         output but not raw.
 
         It is possible to also give a custom cursor through the
@@ -682,7 +824,7 @@ class CMySQLConnection(MySQLConnectionAbstract):
         mysql.connector.cursor_cext.CMySQLCursor.
 
         Raises ProgrammingError when cursor_class is not a subclass of
-        CursorBase. Raises ValueError when cursor is not available.
+        CMySQLCursor. Raises ValueError when cursor is not available.
 
         Returns instance of CMySQLCursor or subclass.
 
@@ -691,13 +833,18 @@ class CMySQLConnection(MySQLConnectionAbstract):
         :param prepared: Return a cursor which uses prepared statements
         :param cursor_class: Use a custom cursor class
         :param dictionary: Rows are returned as dictionary
-        :param named_tuple: Rows are returned as named tuple
         :return: Subclass of CMySQLCursor
         :rtype: CMySQLCursor or subclass
         """
         self.handle_unread_result(prepared)
         if not self.is_connected():
             raise OperationalError("MySQL Connection not available.")
+        if read_timeout or write_timeout:
+            warnings.warn(
+                """The use of read_timeout after the connection has been established is unsupported
+                in the C-Extension""",
+                category=Warning,
+            )
         if cursor_class is not None:
             if not issubclass(cursor_class, CMySQLCursor):
                 raise ProgrammingError(
@@ -715,8 +862,6 @@ class CMySQLConnection(MySQLConnectionAbstract):
             cursor_type |= 2
         if dictionary is True:
             cursor_type |= 4
-        if named_tuple is True:
-            cursor_type |= 8
         if prepared is True:
             cursor_type |= 16
 
@@ -727,20 +872,16 @@ class CMySQLConnection(MySQLConnectionAbstract):
             3: CMySQLCursorBufferedRaw,
             4: CMySQLCursorDict,
             5: CMySQLCursorBufferedDict,
-            8: CMySQLCursorNamedTuple,
-            9: CMySQLCursorBufferedNamedTuple,
             16: CMySQLCursorPrepared,
-            18: CMySQLCursorPreparedRaw,
             20: CMySQLCursorPreparedDict,
-            24: CMySQLCursorPreparedNamedTuple,
         }
         try:
             return (types[cursor_type])(self)
         except KeyError:
-            args = ("buffered", "raw", "dictionary", "named_tuple", "prepared")
+            args = ("buffered", "raw", "dictionary", "prepared")
             raise ValueError(
                 "Cursor not available with given criteria: "
-                + ", ".join([args[i] for i in range(5) if cursor_type & (1 << i) != 0])
+                + ", ".join([args[i] for i in range(4) if cursor_type & (1 << i) != 0])
             ) from None
 
     @property
@@ -779,7 +920,7 @@ class CMySQLConnection(MySQLConnectionAbstract):
 
     def prepare_for_mysql(
         self, params: ParamsSequenceOrDictType
-    ) -> Union[Sequence[bytes], Dict[str, bytes],]:
+    ) -> Union[Sequence[bytes], Dict[bytes, bytes]]:
         """Prepare parameters for statements
 
         This method is use by cursors to prepared parameters found in the
@@ -787,7 +928,7 @@ class CMySQLConnection(MySQLConnectionAbstract):
 
         Returns dict.
         """
-        result: Union[List[Any], Dict[str, Any]] = []
+        result: Union[List[bytes], Dict[bytes, bytes]] = []
         if isinstance(params, (list, tuple)):
             if self.converter:
                 result = [
@@ -804,14 +945,14 @@ class CMySQLConnection(MySQLConnectionAbstract):
             result = {}
             if self.converter:
                 for key, value in params.items():
-                    result[key] = self.converter.quote(
+                    result[key.encode()] = self.converter.quote(
                         self.converter.escape(
                             self.converter.to_mysql(value), self._sql_mode
                         )
                     )
             else:
                 for key, value in params.items():
-                    result[key] = self._cmysql.convert_to_mysql(value)[0]
+                    result[key.encode()] = self._cmysql.convert_to_mysql(value)[0]
         else:
             raise ProgrammingError(
                 f"Could not process parameters: {type(params).__name__}({params}),"
@@ -832,12 +973,13 @@ class CMySQLConnection(MySQLConnectionAbstract):
         username: str = "",
         password: str = "",
         database: str = "",
-        charset: int = 45,
+        charset: Optional[int] = None,
         password1: str = "",
         password2: str = "",
         password3: str = "",
         oci_config_file: Optional[str] = None,
         oci_config_profile: Optional[str] = None,
+        openid_token_file: Optional[str] = None,
     ) -> None:
         """Change the current logged in user"""
         try:
@@ -850,14 +992,24 @@ class CMySQLConnection(MySQLConnectionAbstract):
                 password3,
                 oci_config_file,
                 oci_config_profile,
+                openid_token_file,
             )
 
         except MySQLInterfaceError as err:
-            raise get_mysql_exception(
-                msg=err.msg, errno=err.errno, sqlstate=err.sqlstate
-            ) from err
+            if hasattr(err, "errno"):
+                raise get_mysql_exception(
+                    err.errno, msg=err.msg, sqlstate=err.sqlstate
+                ) from err
+            raise InterfaceError(str(err)) from err
 
-        self._charset_id = charset
+        # If charset isn't defined, we use the same charset ID defined previously,
+        # otherwise, we run a verification and update the charset ID.
+        if charset is not None:
+            if not isinstance(charset, int):
+                raise ValueError("charset must be an integer")
+            if charset < 0:
+                raise ValueError("charset should be either zero or a postive integer")
+            self._charset_id = charset
         self._user = username  # updating user accordingly
         self._post_connection()
 
@@ -874,15 +1026,17 @@ class CMySQLConnection(MySQLConnectionAbstract):
             self._post_connection()
         return res
 
+    @cmd_refresh_verify_options()
     def cmd_refresh(self, options: int) -> Optional[CextEofPacketType]:
-        """Send the Refresh command to the MySQL server"""
         try:
             self.handle_unread_result()
             self._cmysql.refresh(options)
         except MySQLInterfaceError as err:
-            raise get_mysql_exception(
-                msg=err.msg, errno=err.errno, sqlstate=err.sqlstate
-            ) from err
+            if hasattr(err, "errno"):
+                raise get_mysql_exception(
+                    err.errno, msg=err.msg, sqlstate=err.sqlstate
+                ) from err
+            raise InterfaceError(str(err)) from err
 
         return self.fetch_eof_status()
 
@@ -891,7 +1045,11 @@ class CMySQLConnection(MySQLConnectionAbstract):
         self.close()
 
     def cmd_shutdown(self, shutdown_type: Optional[int] = None) -> None:
-        """Shut down the MySQL Server"""
+        """Shut down the MySQL Server
+
+        This method sends the SHUTDOWN command to the MySQL server.
+        The `shutdown_type` is not used, and it's kept for backward compatibility.
+        """
         if not self._cmysql:
             raise OperationalError("MySQL Connection not available")
 
@@ -905,9 +1063,11 @@ class CMySQLConnection(MySQLConnectionAbstract):
         try:
             self._cmysql.shutdown(level)
         except MySQLInterfaceError as err:
-            raise get_mysql_exception(
-                msg=err.msg, errno=err.errno, sqlstate=err.sqlstate
-            ) from err
+            if hasattr(err, "errno"):
+                raise get_mysql_exception(
+                    err.errno, msg=err.msg, sqlstate=err.sqlstate
+                ) from err
+            raise InterfaceError(str(err)) from err
         self.close()
 
     def cmd_statistics(self) -> StatsPacketType:
@@ -918,31 +1078,37 @@ class CMySQLConnection(MySQLConnectionAbstract):
             stat = self._cmysql.stat()
             return MySQLProtocol().parse_statistics(stat, with_header=False)
         except (MySQLInterfaceError, InterfaceError) as err:
-            raise get_mysql_exception(
-                msg=err.msg, errno=err.errno, sqlstate=err.sqlstate
-            ) from err
+            if hasattr(err, "errno"):
+                raise get_mysql_exception(
+                    err.errno, msg=err.msg, sqlstate=err.sqlstate
+                ) from err
+            raise InterfaceError(str(err)) from err
 
     def cmd_process_kill(self, mysql_pid: int) -> None:
         """Kill a MySQL process"""
         if not isinstance(mysql_pid, int):
             raise ValueError("MySQL PID must be int")
-        self.info_query(f"KILL {mysql_pid}")
+        self.cmd_query(f"KILL {mysql_pid}")
 
-    def cmd_debug(self) -> Any:
+    def cmd_debug(self) -> NoReturn:
         """Send the DEBUG command"""
         raise NotImplementedError
 
-    def cmd_ping(self) -> Any:
+    def cmd_ping(self) -> NoReturn:
         """Send the PING command"""
         raise NotImplementedError
 
-    def cmd_query_iter(self, statements: Any) -> Any:
+    def cmd_query_iter(self, statements: str, **kwargs: Any) -> NoReturn:
         """Send one or more statements to the MySQL server"""
         raise NotImplementedError
 
     def cmd_stmt_send_long_data(
-        self, statement_id: Any, param_id: Any, data: Any
-    ) -> Any:
+        self,
+        statement_id: CMySQLPrepStmt,  # type: ignore[override]
+        param_id: int,
+        data: BinaryIO,
+        **kwargs: Any,
+    ) -> NoReturn:
         """Send data for a column"""
         raise NotImplementedError
 
